//
//  QHVCPlayerEnum.h
//  QHVCPlayerKit
//
//  Created by yeenlong on 2020/10/27.
//  Copyright © 2020 qihoo 360. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 播放器播放视频的类型
 */
typedef NS_ENUM(NSInteger, QHVCPlayType)
{
    QHVCPlayTypeLive     = 0,//直播
    QHVCPlayTypeVod      = 1,//点播
};

//直播用
typedef NS_ENUM(NSInteger, QHVCStreamType)
{
    QHVCStreamTypeOnlyAudio = 0,//仅音频
    QHVCStreamTypeOnlyVideo = 1,//仅视频
    QHVCStreamTypeDefault = 2,//默认方式（音、视频）
};

/**
 播放器渲染模式
 */
typedef NS_ENUM(NSInteger, QHVCPlayerRenderMode)
{
    QHVCPlayerRenderModeIn   = 0,//默认，窗口内缩放，不填充屏幕
    QHVCPlayerRenderModeOut  = 1,//填充整个屏幕，可能丢失显示内容，但不会变形
    QHVCPlayerRenderModeFull = 2,//全屏显示，可能会变形
};

///**
// 播放器声音权限
// */
//typedef NS_ENUM(NSInteger, QHVCAudioSessionCategory)
//{
//    QHVCAudioSessionCategoryPlayback   = 0,     //默认
//    QHVCAudioSessionCategoryAmbient  = 1,       //混音
//    QHVCAudioSessionCategorySoloAmbient = 2,    //声音独占
//    QHVCAudioSessionCategoryPlayAndRecord = 3,  //播放录制
//};

typedef NS_ENUM(NSInteger, QHVCDecryptType)
{
    QHVCDecryptType_FFMPEG = 0, //mp4
    QHVCDecryptType_SHUIDI,
    QHVCDecryptType_DISHI
};

/**
 定义播放器错误信息
 */
typedef NS_ENUM(NSInteger, QHVCPlayerError)
{
    QHVCPlayerErrorPlayerInitFailed  = 1,//播放器初始化失败
    QHVCPlayerErrorConnectFailed     = 2,//播放器连接失败，比如网络连接
    QHVCPlayerErrorFormatNotSupport  = 3,//文件格式不支持
    QHVCPlayerErrorFileNotOpen       = 4,//文件打开失败
};

/**
 播放器详细错误信息
 */
typedef NS_ENUM(NSInteger, QHVCPlayerErrorDetailedInfo)
{
    //播放器内部错误
    QHVCPlayerErrorDetailedInfoUnknow                    = 0,//未知消息
    QHVCPlayerErrorDetailedInfoIOException               = 1,//I/O异常
    QHVCPlayerErrorDetailedInfoConnectRefused            = 2,//拒绝连接
    QHVCPlayerErrorDetailedInfoInvalidData               = 3,//无效的数据
    QHVCPlayerErrorDetailedInfoExit                      = 4,//退出，可能注册了无效的过滤器
    QHVCPlayerErrorDetailedInfoNotBitstream              = 5,//找不到Bitstream
    QHVCPlayerErrorDetailedInfoNotDecoder                = 6,//找不到解码器
    QHVCPlayerErrorDetailedInfoNotDemuxer                = 7,//找不到demuxer
    QHVCPlayerErrorDetailedInfoNotFilter                 = 8,//找不到Filter
    QHVCPlayerErrorDetailedInfoNotProtocol               = 9,//找不到Protocol
    QHVCPlayerErrorDetailedInfoNotStream                 = 10,//找不到Stream
    QHVCPlayerErrorDetailedInfoServer                    = 11,//server 错误
    QHVCPlayerErrorDetailedInfoEOF                       = 12,//EOF
    //SDK层错误
    QHVCPlayerErrorDetailedInfoHandleError               = 13,//播放器初始化handle为空
    QHVCPlayerErrorDetailedInfoNotReadyToPlay            = 14,//prepare failed
};

/**
 播放器状态
 */
typedef NS_ENUM(NSInteger, QHVCPlayerStatus)
{
    QHVCPlayerStatusUnknown              = 0,//未知类型
    QHVCPlayerStatusPlaying              = 1,//播放
    QHVCPlayerStatusPaused               = 2,//暂停
    QHVCPlayerStatusStoped               = 3,//会话关闭
};

/**
 直播资源编码类型
 */
typedef NS_ENUM(NSInteger, QHVCPlayerDecodingType)
{
    QHVCMediaInfoDecodeFormateH264    = 0,//正在解码的是h264
    QHVCMediaInfoDecodeFormateH265    = 1,//正在解码的是h265
};

/**
 播放器播放模式,注意流畅模式与低延时模式是互斥的
 */
typedef NS_ENUM(NSInteger, QHVCPlayMode)
{
    QHVCPlayModeFluency      = 1,//流畅模式
    QHVCPlayModeLowLatency   = (1 << 1),//低延迟模式
    QHVCPlayModeLive_IOT     = (1 << 2),//IOT
    QHVCPlayModeNoAVSync     = (1 << 3),//音视频不做同步
};

typedef NS_ENUM(NSInteger, QHVCRecorderFormat)
{
    QHVCRecordFormatDefault = 0,//默认方式（音、视频）
    QHVCRecordFormatOnlyAudio = 1,//仅音频
    QHVCRecordFormatOnlyVideo = 2,//仅视频
};

typedef NS_ENUM(NSInteger,QHVCTranscodeType)
{
    QHVCTranscodeTypeShared = 0, //多路流合为1路流（双摄相机）
    QHVCTranscodeTypePNG = 1, //图片合成为一个视频,图片命名规则iot-%d.png
    QHVCTranscodeTypeJPG = 2, //图片合成为一个视频,图片命名规则iot-%d.jpg
    QHVCTranscodeTypeNormal = 3, //标准转码
    QHVCTranscodeTypeNormalAAC = 4, //标准转码(含AAC)
    QHVCTranscodeTypeOnlyAAC = 5 //只转码音频
};

typedef struct
{
    int width;
    int height;
    int video_bitrate;
    
    int audio_bitrate;
    int samplerate;
    int channels;
    int fps;
    float rotate;
}QHVCRecordConfig;


typedef enum
{
    QHVC_PACKET_TYPE_NONE = 0,
    QHVC_PACKET_TYPE_H264,
    QHVC_PACKET_TYPE_H265,
    QHVC_PACKET_TYPE_AAC,
    QHVC_PACKET_TYPE_OPUS,
    QHVC_PACKET_TYPE_PCM_S16LE,
    QHVC_PACKET_TYPE_PCM_MULAW,
    QHVC_PACKET_TYPE_PCM_ALAW,
    QHVC_PACKET_TYPE_PCM_G726LE,
    QHVC_PACKET_TYPE_MJPEG
}QHVC_PACKET_TYPE;

typedef struct QHVCPacket
{
    void    * _Nonnull opaque;//packet
    uint8_t * _Nonnull pData;
    int                size;
    QHVC_PACKET_TYPE   flags;
    int                isAvcc;
    int                isAdts;
}QHVCPacket;

typedef struct QHVCStatus {
    int play_type;   //0:live  1:vod
    int play_mode;   //0:fluence 1:lowlatency 2:iot
    int stream_type; //0:audioonly 1:videoonly 2:both
    int64_t video_buffer_size; //包个数
    int64_t video_buffer_ms;   //ms
    int64_t audio_buffer_size; //包个数
    int64_t audio_buffer_ms;   //ms
    int64_t avsync;            //ms a-v
    int64_t max_buffer_ms;     //最大缓冲数据量ms
    int64_t max_delay_ms;      //最大延迟
}QHVCStatus;

typedef struct QHVCStreamCodecContext
{
    int sample_rate;
    int nb_channels;
    int sample_bits;
}QHVCStreamCodecContext;

typedef NS_ENUM(NSUInteger, QHVCPlayerUndistortType) {
    QHVCPlayerUndistortTypeBarrel, //桶形
    QHVCPlayerUndistortTypeFish, //鱼眼
};

typedef NS_ENUM(NSUInteger, QHVCPlayerUndistortParamType) {
    QHVCPlayerUndistortParamTypeBarrelIntensityX, //桶形畸变校正参数，水平方向强度系数，取值范围0-100
    QHVCPlayerUndistortParamTypeBarrelIntensityY, //桶形畸变校正参数，垂直方向强度系数，取值范围0-100
    QHVCPlayerUndistortParamTypeBarrelScaleX, //桶形畸变校正参数，水平方向缩放系数，取值范围0-100
    QHVCPlayerUndistortParamTypeBarrelScaleY, //桶形畸变校正参数，垂直方向缩放系数，取值范围0-100
    QHVCPlayerUndistortParamTypeFishFour, //鱼眼畸变校正参数,是否四个视角同时显示，取值范围0，非0；0表示显示一个视角，非0表示显示四个视角
    QHVCPlayerUndistortParamTypeFishView1Horizontal, //鱼眼畸变校正参数,视角1水平方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView1Vertical, //鱼眼畸变校正参数,视角1垂直方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView2Horizontal, //鱼眼畸变校正参数,视角2水平方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView2Vertical, //鱼眼畸变校正参数,视角2垂直方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView3Horizontal, //鱼眼畸变校正参数,视角3水平方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView3Vertical, //鱼眼畸变校正参数,视角3垂直方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView4Horizontal, //鱼眼畸变校正参数,视角4水平方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
    QHVCPlayerUndistortParamTypeFishView4Vertical, //鱼眼畸变校正参数,视角4垂直方向旋转角度,取值含义表示旋转角度，取值范围为int类型取值范围
};

/**
 转码器状态
 */
typedef NS_ENUM(NSInteger, QHVCConvertStatus)
{
    QHVCConvertStatusReady              = 0,//可以开始下载
    QHVCConvertStatusTranscode          = 1,//正在下载
    QHVCPlayerStatusStopping            = 2,//正在停止
};

/**
 下载器状态
 */
typedef NS_ENUM(NSInteger, QHVCDownloaderStatus)
{
    QHVCDownloaderStatusPrepared            = 0,//可以开始下载
    QHVCDownloaderStatusRunning            = 1,//正在下载
};
